==> tkrat-2.0b8.tar.gz: tkrat-2.0b8/util/rat_dummy.c <==
/* 
 * ratDummy.c --
 *
 *	Provides dummy routines so blt_busy can be linked into tclsh
 *
 *
 * TkRat software and its included text is Copyright 1996-1999 by
 * Martin Forssn
 *
 * The full text of the legal notice is contained in the file called
 * COPYRIGHT, included with this distribution.
 */

#include <tk.h>

void Tk_UnmapWindow(Tk_Window tkwin) {}
int Tk_ConfigureValue(Tcl_Interp * interp, Tk_Window tkwin,
	Tk_ConfigSpec * specs, char * widgRec, char * argvName, int flags) {}
void Tk_CreateEventHandler(Tk_Window token, unsigned long mask,
	Tk_EventProc * proc, ClientData clientData) {}
Tk_Window Tk_CreateWindow(Tcl_Interp * interp, Tk_Window parent, char * name,
	char * screenName) {}
Status XQueryTree(Display *display, Window w, Window *root_return,
	Window *parent_return, Window **children_return,
	unsigned int *nchildren_return) {}
Tk_Window Tk_MainWindow(Tcl_Interp * interp) {}
int Tk_RestackWindow(Tk_Window tkwin, int aboveBelow, Tk_Window other) {}
int Tk_ConfigureInfo (Tcl_Interp * interp, Tk_Window tkwin,
	Tk_ConfigSpec * specs, char * widgRec, char * argvName, int flags) {}
int Tk_ConfigureWidget (Tcl_Interp * interp, Tk_Window tkwin,
	Tk_ConfigSpec * specs, int argc, char ** argv, char * widgRec,
	int flags) {}
void Tk_DefineCursor (Tk_Window window, Tk_Cursor cursor) {}
void Tk_DeleteEventHandler (Tk_Window token, unsigned long mask,
	Tk_EventProc * proc, ClientData clientData) {}
void Tk_DestroyWindow (Tk_Window tkwin) {}
void Tk_FreeOptions (Tk_ConfigSpec * specs, char * widgRec, Display * display,
	int needFlags) {}
void Tk_MakeWindowExist (Tk_Window tkwin) {}
void Tk_ManageGeometry (Tk_Window tkwin, Tk_GeomMgr * mgrPtr,
	ClientData clientData) {}
void Tk_MapWindow (Tk_Window tkwin) {}
void Tk_MoveResizeWindow (Tk_Window tkwin, int x, int y, int width,
	int height) {}
Tk_Window Tk_NameToWindow (Tcl_Interp * interp, char * pathName,
	Tk_Window tkwin) {}
void Tk_SetClass (Tk_Window tkwin, char * className) {}
void Tk_UndefineCursor (Tk_Window window) {}
void Tk_HandleEvent (XEvent * eventPtr) {}
int XFree(void *data) {}
int XMapWindow(Display *display, Window w) {}
int XConfigureWindow(Display *display, Window w, unsigned int value_mask,
	XWindowChanges *values) {}
extern Window XCreateWindow(Display *display, Window parent, int x, int y, 
	unsigned int width, unsigned int height, unsigned int border_width,
	int depth, unsigned int class, Visual *visual, unsigned long valuemask,
	XSetWindowAttributes *attributes) {}

int
Rat_dummy_Init(Tcl_Interp *interp)
{
    return TCL_OK;
}

==> tkrat_2.0.3.orig.tar.gz: tkrat-2.0.3/util/rat_dummy.c <==
/* 
 * ratDummy.c --
 *
 *	Provides dummy routines so blt_busy can be linked into tclsh
 *
 *
 * TkRat software and its included text is Copyright 1996-2000 by
 * Martin Forssn
 *
 * The full text of the legal notice is contained in the file called
 * COPYRIGHT, included with this distribution.
 */

#include <tk.h>

void Tk_UnmapWindow(Tk_Window tkwin) {}
int Tk_ConfigureValue(Tcl_Interp * interp, Tk_Window tkwin,
	Tk_ConfigSpec * specs, char * widgRec, char * argvName, int flags) {}
void Tk_CreateEventHandler(Tk_Window token, unsigned long mask,
	Tk_EventProc * proc, ClientData clientData) {}
Tk_Window Tk_CreateWindow(Tcl_Interp * interp, Tk_Window parent, char * name,
	char * screenName) {}
Status XQueryTree(Display *display, Window w, Window *root_return,
	Window *parent_return, Window **children_return,
	unsigned int *nchildren_return) {}
Tk_Window Tk_MainWindow(Tcl_Interp * interp) {}
int Tk_RestackWindow(Tk_Window tkwin, int aboveBelow, Tk_Window other) {}
int Tk_ConfigureInfo (Tcl_Interp * interp, Tk_Window tkwin,
	Tk_ConfigSpec * specs, char * widgRec, char * argvName, int flags) {}
int Tk_ConfigureWidget (Tcl_Interp * interp, Tk_Window tkwin,
	Tk_ConfigSpec * specs, int argc, char ** argv, char * widgRec,
	int flags) {}
void Tk_DefineCursor (Tk_Window window, Tk_Cursor cursor) {}
void Tk_DeleteEventHandler (Tk_Window token, unsigned long mask,
	Tk_EventProc * proc, ClientData clientData) {}
void Tk_DestroyWindow (Tk_Window tkwin) {}
void Tk_FreeOptions (Tk_ConfigSpec * specs, char * widgRec, Display * display,
	int needFlags) {}
void Tk_MakeWindowExist (Tk_Window tkwin) {}
void Tk_ManageGeometry (Tk_Window tkwin, Tk_GeomMgr * mgrPtr,
	ClientData clientData) {}
void Tk_MapWindow (Tk_Window tkwin) {}
void Tk_MoveResizeWindow (Tk_Window tkwin, int x, int y, int width,
	int height) {}
Tk_Window Tk_NameToWindow (Tcl_Interp * interp, char * pathName,
	Tk_Window tkwin) {}
void Tk_SetClass (Tk_Window tkwin, char * className) {}
void Tk_UndefineCursor (Tk_Window window) {}
void Tk_HandleEvent (XEvent * eventPtr) {}
int XFree(void *data) {}
int XMapWindow(Display *display, Window w) {}
int XConfigureWindow(Display *display, Window w, unsigned int value_mask,
	XWindowChanges *values) {}
extern Window XCreateWindow(Display *display, Window parent, int x, int y, 
	unsigned int width, unsigned int height, unsigned int border_width,
	int depth, unsigned int class, Visual *visual, unsigned long valuemask,
	XSetWindowAttributes *attributes) {}
Tk_PhotoHandle Tk_FindPhoto (Tcl_Interp *interp, char *imageName) {return NULL;}
int Tk_PhotoGetImage(Tk_PhotoHandle hd, Tk_PhotoImageBlock *blockPtr){return 0;}

int
Rat_dummy_Init(Tcl_Interp *interp)
{
    return TCL_OK;
}
